@@ -8,7 +8,7 @@
 #   The Artistic License 2.0 (GPL Compatible)
 #
 package Redis;
-$Redis::VERSION = '1.979';
+$Redis::VERSION = '1.980';
 # ABSTRACT: Perl binding for Redis database
 # VERSION
 # AUTHORITY
@@ -904,7 +904,7 @@ Redis - Perl binding for Redis database
 
 =head1 VERSION
 
-version 1.979
+version 1.980
 
 =head1 SYNOPSIS
 
@@ -1703,9 +1703,11 @@ Set the value and expiration in milliseconds of a key (see L<http://redis.io/com
 
 =head2 set
 
-  $r->set(key, value, [EX seconds], [PX milliseconds], [NX|XX])
+  $r->set(key, value, ['EX',  seconds], ['PX', milliseconds], ['NX'|'XX'])
 
-Set the string value of a key (see L<http://redis.io/commands/set>)
+Set the string value of a key (see L<http://redis.io/commands/set>). Example:
+
+  $r->set('key', 'test', 'EX', 60, 'NX')
 
 =head2 setbit
 
